/*
 * Copyright © 2020-2023 Fachhochschule für die Wirtschaft (FHDW) Hannover
 *
 * This file is part of gaming-core.
 *
 * Gaming-core is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * Gaming-core is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * gaming-core. If not, see <http://www.gnu.org/licenses/>.
 */
package de.fhdw.gaming.core.ui.type;

import java.util.Optional;

import de.fhdw.gaming.core.ui.InputProviderException;

/**
 * Represents the type of an integer field.
 */
public final class IntegerFieldType implements FieldType<Integer> {

    /**
     * The default value.
     */
    private final Optional<Integer> defaultValue;

    /**
     * Creates an {@link IntegerFieldType}.
     *
     * @param defaultValue The default value.
     */
    public IntegerFieldType(final Optional<Integer> defaultValue) {
        this.defaultValue = defaultValue;
    }

    @Override
    public void accept(final FieldTypeVisitor visitor) throws FieldTypeException {
        visitor.handle(this);
    }

    @Override
    public Optional<Integer> getDefaultValue() {
        return this.defaultValue;
    }

    @Override
    public Optional<String> getInfo() {
        return Optional.of("The value must be an integer number.");
    }

    @Override
    public Integer postInput(final String id, final String value) throws InputProviderException {
        try {
            return Integer.valueOf(value);
        } catch (final NumberFormatException e) {
            throw new InputProviderException(this.getInfo().orElseThrow(), e);
        }
    }
}
