package de.fhdw.gaming.core.ui.type.validator;

import de.fhdw.gaming.core.ui.InputProviderException;

/**
 * Validates against a minimum value.
 *
 * @param <T> The type of value.
 */
public final class MinValueValidator<T extends Comparable<T>> implements Validator<T> {

    /**
     * The minimum value.
     */
    private final T minValue;

    /**
     * Creates a {@link MinValueValidator}.
     *
     * @param minValue The minimum value.
     */
    public MinValueValidator(final T minValue) {
        this.minValue = minValue;
    }

    @Override
    public T validate(final T value) throws InputProviderException {
        if (value.compareTo(this.minValue) < 0) {
            throw new InputProviderException(this.getInfo());
        } else {
            return value;
        }
    }

    @Override
    public String getInfo() {
        return String.format("The value must be at least %s.", this.minValue);
    }
}
